# SuperGLU
Main Generalized Learning Utilities (GLU) library for communicating data between different learning technologies and intelligent systems.

Adding unit tests and porting additional functionality from original closed-source version still being finalized.

Requires:

Technically Optional, But Important:
- rhino.js: For unit testing of JS from inside Python unit tests.
- buster.js: For JS, by JS Unit Testing
- lxml: At least if you want xml stuff to work